# CREATE-DISCORD-BOT

An opinionated cli-tool to bootstrap your discord bot code!

#### FEATURES

- Support for code with/without cogs.
- .env file support for keys and .gitignore to hide it.
- Bot code pre-built with a ping function to get you started!

## Usage

- Install using

```
pip install bootstrap-discord-bot
```

- cd into your bot directory

- Run `bootstrap-discord-bot -h` to get help

![img](https://i.ibb.co/vmgnDKD/Screenshot-from-2020-09-19-16-48-04.png)

- Run `bootstrap-discord-bot --cogs` to initialise a discord bot with cogs.

![img](https://i.ibb.co/JKJFT9h/unknown.png)

- Run `boostrap-discord-bot --nocogs` to initialise a discord bot without cogs.

![img](https://i.ibb.co/yfd7GKb/Screenshot-from-2020-09-19-16-54-13.png)

## Built using

- Python
- Discord.py
- argparse
- setuptools
